# coding:utf-8
import os

import matplotlib.pyplot as plt
import numpy as np
from pymatgen.electronic_structure.plotter import BSPlotterProjected

from dspawpy.io.read import get_band_data

datafile = "dspawpy_proj/dspawpy_tests/inputs/supplement/pband.h5"  # 指定数据文件路径
band_data = get_band_data(
    band_dir=datafile,
    syst_dir=None,  # system.json文件路径，仅当band_dir为json文件时需要
    efermi=None,  # 用于手动修正费米能级
    zero_to_efermi=True,  # 非金属体系应将零点能移动到费米能级
)

bsp = BSPlotterProjected(bs=band_data)
# ! 指定元素和轨道和原子序号
dict_elem_orbit = {"Mo": ["px", "py", "pz"]}
dict_elem_index = {"Mo": [1]}

axes_or_plt = bsp.get_projected_plots_dots_patom_pmorb(
    dictio=dict_elem_orbit,  # 指定元素-轨道字典
    dictpa=dict_elem_index,  # 指定元素-原子序号字典
    sum_atoms=None,  # 是否对原子求和
    sum_morbs=None,  # 是否对轨道求和
    zero_to_efermi=False,  # 上面读取数据时已经平移，此处应关闭
    ylim=None,  # 设置能量范围
    vbm_cbm_marker=False,  # 是否标记导带底和价带顶
    selected_branches=None,  # 指定绘制的能带分支
    w_h_size=(12, 8),  # 设置图片宽高
    num_column=None,  # 设置每行显示的图片数量
)

if isinstance(axes_or_plt, plt.Axes):
    fig = axes_or_plt.get_figure()  # version newer than v2023.8.10
elif np.iterable(axes_or_plt):
    fig = np.asarray(axes_or_plt).flatten()[0].get_figure()
else:
    fig = axes_or_plt.gcf()  # older version pymatgen

# 添加能量零点参考线
for ax in fig.axes:
    ax.axhline(0, lw=2, ls="-.", color="gray")

figname = (
    "dspawpy_proj/dspawpy_tests/outputs/us/4band_patom_porbit.png"  # 输出的能带图文件名
)
os.makedirs(os.path.dirname(os.path.abspath(figname)), exist_ok=True)
fig.savefig(figname, dpi=300)
